/*
 * This file is a part of KEMET project (Library).
 * 
 * Copyright (C) 2008 MAUPIN Fabrice
 *
 * This library is free software; 
 * you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License 
 * as published by the Free Software Foundation; 
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this library; 
 * if not, write to the Free Software Foundation, 
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 */
package org.kemet.tests;

import java.util.HashMap;
import java.util.Locale;
import java.util.TreeMap;

import junit.framework.TestCase;

import org.apache.log4j.Logger;
import org.junit.Before;
import org.kemet.impl.grammar.GrammarManager;
import org.kemet.impl.grammar.IGlobals;
import org.kemet.impl.grammar.exceptions.KemetAPIException;
import org.kemet.impl.grammar.integration.HieroglyphManager;
import org.kemet.impl.grammar.integration.TransliterationManager;
import org.kemet.message.Messages;

/**
 * 
 * @author fabricemaupin
 * 
 * <p>
 * <b>define global attributes for tests classes.</b>
 * </p>
 * 
 * 
 * @since 0.6
 * 
 */
public abstract class TestRoot extends TestCase implements IGlobals, IAttr {
	static Logger log = Logger.getLogger("org.kemet.tests");

	/**
	 * <p>
	 * <b>current transliterationToolbox manager.</b>
	 * </p>
	 */
	protected TransliterationManager transliteration;

	/**
	 * <p>
	 * <b>current hieroglyph toolbox manager.</b>
	 * </p>
	 */
	protected HieroglyphManager hieroglyph;

	/**
	 * <p>
	 * <b>list of phonograms.</b>
	 * </p>
	 */
	protected HashMap<String, String> phInfo;

	/**
	 * <p>
	 * <b>list of sorted phonograms.</b>
	 * </p>
	 */
	protected TreeMap<String, String[]> sortedPhInfo;

	/**
	 * <p>
	 * <b>current grammar manager.</b>
	 * </p>
	 */
	protected GrammarManager gm;

	/**
	 * <p>
	 * <b>list of parameters.</b>
	 * </p>
	 */
	protected HashMap args;

	/**
	 * <p>
	 * <b>current results.</b>
	 * </p>
	 */
	protected String[] result;

	/**
	 * <p>
	 * <b>current sequence.</b>
	 * </p>
	 */
	protected String sequence;

	/**
	 * <p>
	 * <b>initialization method to custom in test classes.</b>
	 * </p>
	 */
	public abstract void init();

	/**
	 * <p>
	 * <b>set the parameters before execute the tests.</b>
	 * </p>
	 * 
	 * @since 0.6
	 */
	@Before
	public void setUp() {
		// initilialize the locales...
		Messages.setRESOURCE_BUNDLE(Locale.getDefault());

		org.kemet.message.Messages.setRESOURCE_BUNDLE(Locale.getDefault());
		org.kemet.orm.Messages.setRESOURCE_BUNDLE(Locale.getDefault());

		// initialize the parameters...
		args = new HashMap();

		args.put("XMLPath", XMLPath);
		args.put("file1", file1);
		args.put("file2", file2);
		args.put("file3", file3);

		args.put("encoding", "UTF-8");

		args.put("SupportedSequenceFormats", SupportedSequenceFormats);

		args.put("methodNameToManageTransliteration",
				methodNameToManageTransliteration);
		args
				.put("methodNameToManageHieroglyphs",
						methodNameToManageHieroglyphs);

		args.put("methodNameToPhoneticRead", methodNameToPhoneticRead);

		args.put("methodNameToPhoneticReadWithGlobalApproach",
				methodNameToPhoneticReadWithGlobalApproach);

		// initialize the grammar manager...
		try {
			gm = new GrammarManager(selectedGrammar + "."
					+ grammarMainClassName, args);

			gm.setNumberOfConsomns(3);

			// get the phonograms...
			phInfo = org.kemet.impl.grammar.model.Phonogram.getAllPhonograms();

			sortedPhInfo = org.kemet.impl.grammar.model.Phonogram
					.getAllSortedPhonograms();
		} catch (KemetAPIException e) {
			e.printStackTrace();
			assertTrue(false);
		}

		// custom initialization...
		init();
	}

	/**
	 * <p>
	 * <b>return the localized type.</b>
	 * </p>
	 * 
	 * @param currentType
	 *            type to localized
	 * @return localized type
	 * 
	 * @since 0.6
	 */
	public static String getFormatType(String currentType) {
		return "[" + Messages.getString(currentType) + "]";
	}
}
